@@ -109,7 +109,7 @@ struct _GVolumeMonitorClass
                                       const char     *uuid);
 
 
-  /* These arguments are unfortunately backwards by mistake (bug #520169) */
+  /* These arguments are unfortunately backwards by mistake (bug #520169). Deprecated in 2.20. */
   GVolume * (* adopt_orphan_mount)   (GMount         *mount,
                                       GVolumeMonitor *volume_monitor);
 
@@ -117,6 +117,10 @@ struct _GVolumeMonitorClass
   void      (* drive_eject_button)   (GVolumeMonitor *volume_monitor,
                                       GDrive         *drive);
 
+  /* signal added in 2.21 */
+  void      (* drive_stop_button)   (GVolumeMonitor *volume_monitor,
+                                     GDrive         *drive);
+
   /*< private >*/
   /* Padding for future expansion */
   void (*_g_reserved1) (void);
@@ -125,7 +129,6 @@ struct _GVolumeMonitorClass
   void (*_g_reserved4) (void);
   void (*_g_reserved5) (void);
   void (*_g_reserved6) (void);
-  void (*_g_reserved7) (void);
 };
 
 GType           g_volume_monitor_get_type             (void) G_GNUC_CONST;
@@ -139,7 +142,9 @@ GVolume *       g_volume_monitor_get_volume_for_uuid  (GVolumeMonitor *volume_mo
 GMount *        g_volume_monitor_get_mount_for_uuid   (GVolumeMonitor *volume_monitor,
                                                        const char     *uuid);
 
+#ifndef G_DISABLE_DEPRECATED
 GVolume *       g_volume_monitor_adopt_orphan_mount   (GMount         *mount);
+#endif
 
 G_END_DECLS
 
